/*	$LAAS$ */
/*
 * Copyright (c) 2005 CNRS/LAAS
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <pthread.h>
#include <stdio.h>
#include <stdarg.h>
#include <stdlib.h>

#include <portLib.h>
#include <h2initGlob.h>
#include "fh2805/fh2805.h"

int
main(int argc, char *argv[])
{
	fh2805dev_t *dev;
	char *name;
	int m, pos;

	if (argc > 2) 
		name = argv[1];
	else
		name = "/dev/ttyS0";

	h2initGlob(0);
	dev = fh2805Init(name, 9600);
	if (dev == NULL) {
		exit(2);
	}
	while (1) {
		printf("0 - quit\n"
		    "1 - reset\n"
		    "2 - read pos\n"
		    "3 - goto\n"
		    "4 - temperature\n"
		    "-> ");
		scanf("%d", &m);
		switch (m) {
		case 0:
			printf("bye\n");
			exit(0);
		case 1:
			fh2805Cmd(dev, GO_HOMING_SEQUENCE);
			while (fh2805Busy(dev))
				;
			printf("reached zero\n");
			fh2805Cmd(dev, SET_ABSOLUTE_POSITION_REFERENCE, 
				  FH2805_JIDO_HOME_POSITION);
			fh2805Cmd(dev, NOTIFY_POSITION_GOAL);
			fh2805Cmd(dev, ENABLE_POSITIONNING_MODE);
			while (fh2805Busy(dev))
				;
			printf("done\n");
			break;
		case 2:
			fh2805Cmd(dev, GET_ACTUAL_POSITION);
			while (fh2805Busy(dev))
				;
			printf("pos: %d\n", dev->pos);
			break;
		case 3:
			printf("Enter desired position -180000..0: ");
			scanf("%d", &pos);
			fh2805Cmd(dev, SET_ABSOLUTE_POSITION_REFERENCE, pos);
			fh2805Cmd(dev, NOTIFY_POSITION_GOAL);
			fh2805Cmd(dev, ENABLE_POSITIONNING_MODE);
			while (fh2805Busy(dev))
				;
			printf("done\n");
			break;
		case 4:
			fh2805Cmd(dev, GET_TEMPERATURE);
			while (fh2805Busy(dev))
				;
			printf("temperature: %d deg C\n", dev->temperature);
			break;
		default:
			printf("unknown command %d\n", m);
			break;
		}
	} /* while */
	exit(0);
}
